@@ -20,6 +20,7 @@ from .resources import (
     CustomerManagedEncryptionStatus,
     Replication,
     ReplicationStatus,
+    Rotation,
     Secret,
     SecretPayload,
     SecretVersion,
@@ -48,6 +49,7 @@ __all__ = (
     "CustomerManagedEncryptionStatus",
     "Replication",
     "ReplicationStatus",
+    "Rotation",
     "Secret",
     "SecretPayload",
     "SecretVersion",
